# Supported Languages

Jupytext works with notebooks in any of the following languages:

- Bash
- C#
- C++
- Clojure
- Coconut
- F#
- Gnuplot
- Go
- Groovy
- Haskell
- IDL
- Java
- Javascript
- Julia
- Logtalk
- Lua
- Matlab
- OCaml
- Octave
- PowerShell
- Python
- q/kdb+
- R
- Robot Framework
- Rust/Evxcr
- Sage
- SAS
- Scala
- Scheme
- Script of Script
- Stata
- Tcl
- TypeScript
- Wolfram Language
  - Note that Jupytext uses the non-standard `.wolfram` file extension for Wolfram Language files to avoid conflicts with Matlab.
- Xonsh

Extending Jupytext to more languages should be easy, see the sections on [contributing to](contributing.md) and [developing](developing.md) Jupytext.
